@@ -21,21 +21,30 @@ proc tclInit {} {
 
     # lookup and emulate "source" of lib/vfs/{vfs*.tcl,mk4vfs.tcl}
     # must use raw MetaKit calls because VFS is not yet in place
-    set d [mk::select exe.dirs parent 0 name lib]
-    set d [mk::select exe.dirs parent $d name vfs]
+    set d [${::tclkitMkNamespace}::select exe.dirs parent 0 name lib]
+    set d [${::tclkitMkNamespace}::select exe.dirs parent $d name vfs]
     
     foreach x {vfsUtils vfslib mk4vfs} {
-      set n [mk::select exe.dirs!$d.files name $x.tcl]
-      set s [mk::get exe.dirs!$d.files!$n contents]
+      set n [${::tclkitMkNamespace}::select exe.dirs!$d.files name $x.tcl]
+      set s [${::tclkitMkNamespace}::get exe.dirs!$d.files!$n contents]
       catch {set s [zlib decompress $s]}
       uplevel #0 $s
     }
 
     # use on-the-fly decompression, if mk4vfs understands that
-    set mk4vfs::zstreamed 1
+    switch -- $::tclkitMkNamespace {
+        "mk" {
+            set mk4vfs::zstreamed 1
+            set vfsimpl "mk4"
+        }
+        "readkit" {
+            set mkcl_vfs::zstreamed 1
+            set vfsimpl "mkcl"
+        }
+    }
 
     # mount the executable, i.e. make all runtime files available
-    vfs::filesystem mount $noe [list ::vfs::mk4::handler exe]
+    vfs::filesystem mount $noe [list ::vfs::${vfsimpl}::handler exe]
 
     # alter path to find encodings
     if {[info tclversion] eq "8.4"} {
@@ -65,7 +74,7 @@ proc tclInit {} {
 
     set tcl_library [file join $noe lib tcl$tcl_version]
     set tcl_libPath [list $tcl_library [file join $noe lib]]
-    vfs::filesystem mount $noe [list ::vfs::mk4::handler exe]
+    vfs::filesystem mount $noe [list ::vfs::${vfsimpl}::handler exe]
   }
   
   # load config settings file if present
@@ -76,4 +85,6 @@ proc tclInit {} {
   
 # reset auto_path, so that init.tcl's search outside of tclkit is cancelled
   set auto_path $tcl_libPath
+
+  unset ::tclkitMkNamespace
 }
